"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var transformLayoutStyleProperties_1 = require("../../styleTransformers/transformLayoutStyleProperties");
var useYogaLayout_1 = require("../../hooks/useYogaLayout");
var transformBlendProperties_1 = require("../../styleTransformers/transformBlendProperties");
var transformGeometryStyleProperties_1 = require("../../styleTransformers/transformGeometryStyleProperties");
var StyleSheet_1 = require("../../helpers/StyleSheet");
var useSelectionChange_1 = require("../../hooks/useSelectionChange");
var transformBorderProperties_1 = require("../../styleTransformers/transformBorderProperties");
var transformAutoLayoutToYoga_1 = require("../../styleTransformers/transformAutoLayoutToYoga");
var useOnLayoutHandler_1 = require("../../hooks/useOnLayoutHandler");
var useImageHash_1 = require("../../hooks/useImageHash");
var useInheritStyle_1 = require("../../hooks/useInheritStyle");
exports.FRAME_PRESETS = {
    iPhoneX: {
        name: 'iPhone X',
        width: 375,
        height: 812
    },
    iPhone8Plus: {
        name: 'iPhone 8 Plus',
        width: 414,
        height: 736
    },
    iPhone8: {
        name: 'iPhone 8',
        width: 375,
        height: 667
    },
    iPhoneSE: {
        name: 'iPhone SE',
        width: 320,
        height: 568
    },
    googlePixel2: {
        name: 'Google Pixel 2',
        width: 411,
        height: 731
    },
    googlePixel2XL: {
        name: 'Google Pixel 2 XL',
        width: 411,
        height: 823
    },
    android: {
        name: 'Android',
        width: 360,
        height: 640
    },
    'iPadMini/9.7': {
        name: 'iPad Mini / 9.7',
        width: 768,
        height: 974
    },
    'iPadPro10.5': {
        name: 'iPad Pro 10.5',
        width: 834,
        height: 1112
    },
    'iPadPro12.9': {
        name: 'iPad Pro 12.9',
        width: 1024,
        height: 1366
    },
    surfacePro3: {
        name: 'Surface Pro 3',
        width: 1440,
        height: 990
    },
    surfacePro4: {
        name: 'Surface Pro 4',
        width: 1368,
        height: 912
    },
    desktop: {
        name: 'Desktop',
        width: 1440,
        height: 1024
    },
    macbook: {
        name: 'Macbook',
        width: 1152,
        height: 700
    },
    macbookPro: {
        name: 'Macbook Pro',
        width: 1440,
        height: 900
    },
    surfaceBook: {
        name: 'Surface Book',
        width: 1500,
        height: 1000
    },
    iMac: {
        name: 'iMac',
        width: 1280,
        height: 720
    },
    appleWatch42mm: {
        name: 'Apple Watch 42mm',
        width: 156,
        height: 195
    },
    appleWatch38mm: {
        name: 'Apple Watch 38mm',
        width: 136,
        height: 170
    },
    a4: {
        name: 'A4',
        width: 595,
        height: 842
    },
    a5: {
        name: 'A5',
        width: 420,
        height: 595
    },
    a6: {
        name: 'A6',
        width: 297,
        height: 420
    },
    letter: {
        name: 'Letter',
        width: 612,
        height: 792
    },
    tabloid: {
        name: 'Tabloid',
        width: 792,
        height: 1224
    },
    twitterPost: {
        name: 'Twitter Post',
        width: 1012,
        height: 506
    },
    twitterHeader: {
        name: 'Twitter Header',
        width: 1500,
        height: 500
    },
    facebookPost: {
        name: 'Facebook Post',
        width: 1200,
        height: 630
    },
    facebookCover: {
        name: 'Facebook Cover',
        width: 820,
        height: 312
    },
    instagramPost: {
        name: 'Instagram Post',
        width: 1080,
        height: 1080
    },
    instagramStory: {
        name: 'Instagram Story',
        width: 1080,
        height: 1920
    },
    dribbbleShot: {
        name: 'Dribbble Shot',
        width: 400,
        height: 300
    },
    dribbbleShotHD: {
        name: 'Dribbble Shot HD',
        width: 800,
        height: 600
    },
    linkedInCover: {
        name: 'LinkedIn Cover',
        width: 1584,
        height: 396
    }
};
var Frame = function (props) {
    var nodeRef = React.useRef();
    useSelectionChange_1.useSelectionChange(nodeRef, props);
    var style = __assign({}, StyleSheet_1.StyleSheet.flatten(props.style), transformAutoLayoutToYoga_1.transformAutoLayoutToYoga(props));
    var imageHash = useImageHash_1.useImageHash(style.backgroundImage);
    var preset = props.preset, propWithoutPreset = __rest(props, ["preset"]);
    var frameProps = __assign({}, (preset || {}), transformLayoutStyleProperties_1.transformLayoutStyleProperties(style), transformBlendProperties_1.transformBlendProperties(style), transformGeometryStyleProperties_1.transformGeometryStyleProperties('backgrounds', style, imageHash), transformBorderProperties_1.transformBorderStyleProperties(style), propWithoutPreset, { style: style });
    var yogaChildProps = useYogaLayout_1.useYogaLayout(__assign({ nodeRef: nodeRef }, frameProps));
    useOnLayoutHandler_1.useOnLayoutHandler(yogaChildProps, props);
    return (React.createElement(useInheritStyle_1.InheritStyleProvider, { style: style },
        React.createElement("frame", __assign({}, frameProps, yogaChildProps, { innerRef: nodeRef }))));
};
exports.Frame = Frame;
//# sourceMappingURL=Frame.js.map